"""
@var __revision__: Revision identifier.
"""

__revision__ = '%K%'

class CommitID(object):
    """
    """

    def __init__(self, seqno, timestamp, systemid, log):
        self._seqno = seqno
        self._timestamp = timestamp / 1000.0
        self._systemid = systemid
        self._log = log

    seqno = property(lambda s: s._seqno, doc="""Sequence number of the CommitID.

                                                On commits on the same resource and the same system this will be a strictly monotonically increasing number.""")
    timestamp = property(lambda s: s._timestamp, doc="""The time the commit was made.

                                                        Floating point number containing unix timestamp (suitable for time.ctime or time.gmtime)""")
    systemid = property(lambda s: s._systemid, doc="""Systemid which the commit was made on.

                                                      This may be different than the system connected if the resource is proxied""")
    log = property(lambda s: s._log, doc="""The commit log message for the corresponding commit.""")

    def __cmp__(self, other):
        if other is None:
            return self.seqno + 1 #One more than zero
        if self.systemid != other.systemid:
            raise ValueError("Can't compare CommitID:s with different systemid")
        return self.seqno - other.seqno

    def __str__(self):
        return "<CommitID SeqNo=%u TimeStamp=%u SystemID=%r Log=%r>" % (self.seqno, self.timestamp, self.systemid, self.log)
    __repr__ = __str__
