from resource import Resource
from thisversion import PLDB
import plutil

"""
This module contains functionality for managing system configuration
on PacketLogic system.

Do NOT import this module directly. The L{PLConnection
<packetlogic2.PLConnection>} object should be used, e.g:

    >>> import packetlogic2
    >>> pl = packetlogic2.connect("192.168.1.25", "admin", "pldemo00")
    >>> l = pl.LogLevels()
    >>> plrcd = l.get("Ruleset")
    >>> plrcd.set(l.DEBUG)
    >>> l.commit()

@var __revision__: Revision identifier.
"""

__revision__ = '%K%'

_Prop_Facility = plutil.Prop('name', 'level', 'index')


class Facility(object):
    __slots__ = ('_prop', '_pldb')

    def __init__(self, _pldb, **props):
        self._pldb = _pldb
        self._prop = _Prop_Facility(**props)

    def __repr__(self):
        return "<PacketLogic LogFacility '%s' '%i'>" % (self._prop.name,
                                                        self._prop.level)

    name = property(lambda self: self._prop.name, doc="name of logfacility")
    level = property(lambda self: self._prop.level, doc="log level")

    def set(self, level):
        self._pldb.session.log_facility_set_level(self._prop.index, level)


class LogLevels(Resource):
    EMERGENCY = PLDB.EMERGENCY
    CRITICAL = PLDB.CRITICAL
    ERROR = PLDB.ERROR
    WARNING = PLDB.WARNING
    NOTICE = PLDB.NOTICE
    INFO = PLDB.INFO
    DEBUG = PLDB.DEBUG
    VERBOSE = PLDB.VERBOSE

    def _resource(self):
        return PLDB.RESOURCE_LOGS

    def list(self):
        lst = plutil._do(self, self.session.log_facility_list(),
                         plutil._ListCB(self, self.session.log_facility_list_handle, lambda **a: Facility(self.session, **a)))
        return lst

    def get(self, name):
        for f in self.list():
            if name == f.name:
                return f
        raise ValueError("Facility %s not found" % name)
