"""
This module contains TunnelTypeObject implementation.

There is no need to import this module directly. Use the methods of
the L{Ruleset object <ruleset.Ruleset>} to create and manipulate
TunnelTypeObjects.

    >>> o = r.object_add("/TunnelTypeObjects/Test")
    >>> o.add("GRE")
    >>> print o.items
    ['GRE']

@var __revision__: Revision identifier.
"""

__revision__ = '%K%'

import plobject
from thisversion import PLDB
import plutil

OBJECT_TYPE = PLDB.OBJECT_TYPE_TUNNELTYPEOBJECT

TUNNELTYPES = {
    PLDB.TUNNEL_TYPE_INVALID: "INVALID",
    PLDB.TUNNEL_TYPE_GTP: "GTP",
    PLDB.TUNNEL_TYPE_ESP: "ESP",
    PLDB.TUNNEL_TYPE_TEREDO: "TEREDO",
    PLDB.TUNNEL_TYPE_GRE: "GRE",
    PLDB.TUNNEL_TYPE_L2TP: "L2TP",
    PLDB.TUNNEL_TYPE_NULL: "NULL",
}
TUNNELTYPEIDS = dict([(v,k) for k,v in TUNNELTYPES.items()])

class TunnelTypeObject(plobject.PLObject):
	"""
	TunnelTypeObject Implementation

	Object path: /TunnelTypeObjects

	@cvar Item: TunnelTypeObject Item implementation.
	"""

	__slots__ = ('_prop', '_pldb', '_callback', '_item_added')

	def __init__(self, **props):
		plobject.PLObject.__init__(self, **props)

	base_path = plutil.roConst("/TunnelTypeObjects", "Only the type portion of the path")
	type = plutil.roConst(OBJECT_TYPE, "Number representing the type of object")

	def _create_item(self, value):
		if isinstance(value, int):
			item = self.Item(self, value=value)
                else:
			if not value in TUNNELTYPEIDS:
                        	raise ValueError("Unknown tunneltype")
                        item = self.Item(self, value=TUNNELTYPEIDS[value])
		return item

	def add(self, value):
		"""
		Adds a TunnelTypeObject item to this TunnelTypeObject.

		@type value: C{str}
		@param value: The value is a string describing the TunnelTypeObject item.

		@rtype: C{None}
		"""
		plobject.PLObject.add(self, value)


	class Item(plobject.PLObject.Item):
		"""
		TunnelTypeObject Item implementation.
		Should not be instantiated, use L{TunnelTypeObject.add} instead.

		@type value: C{int}
		"""
		__slots__ = ('_prop', '_parent')
		_Prop = plutil.Prop(value=int, *plobject._item_props)

		def __str__(self):
                        return TUNNELTYPES.get(self._prop.value, "Unknown(%d)" % self._prop.value)

		value = property(lambda self: self._prop.value, doc="Tunnel type ID")
