"""
This module contains SessionContextObject implementation.

There is no need to import this module directly. Use the methods of
the L{Ruleset object <ruleset.Ruleset>} to create and manipulate
SessionContextObjects.

    >>> o = r.object_add("/SessionContextObjects/Test")
    >>> o.add(schemaname="mydocsisschema", columnname="cmtschannel", value="43")
    >>> print o.items
    ['mydocsisschema:cmtschannel=43']

@var __revision__: Revision identifier.
"""

__revision__ = '%K%'

import plobject
from thisversion import PLDB
import plutil

OBJECT_TYPE = PLDB.OBJECT_TYPE_SESSIONCONTEXTOBJECT

class SessionContextObject(plobject.PLObject):
	"""
	SessionContextObject Implementation

	Object path: /SessionContextObjects

	@cvar Item: SessionContextObject Item implementation.
	"""

	__slots__ = ('_prop', '_pldb', '_callback', '_item_added')

	base_path = plutil.roConst("/SessionContextObjects", "Only the type portion of the path")
	type = plutil.roConst(OBJECT_TYPE, "Number representing the type of object")

	MATCHTYPE_EQUAL = PLDB.SESSIONCONTEXT_MATCHTYPE_EQUAL
	MATCHTYPE_CONTAINS = PLDB.SESSIONCONTEXT_MATCHTYPE_CONTAINS

	def _create_item(self, (schemaname, columnname, value, matchtype)):
		item = self.Item(self, schemaname=schemaname, columnname=columnname, value=value, matchtype=matchtype)
		return item

	def add(self, schemaname, columnname, value, matchtype=MATCHTYPE_EQUAL):
		"""
		Adds a SessionContextObject item to this SessionContextObject.

		@type schema: C{str}
		@param schema: The schemaname of sessioncontext
		@type column: C{str}
		@param column: The columnname of sessioncontext
		@type value: C{str}
		@param value: The value of sessioncontext
		@rtype: C{None}
		@type matchtype: int
		"""
		plobject.PLObject.add(self, (schemaname, columnname, value, matchtype))


	class Item(plobject.PLObject.Item):
		"""
		SessionContextObject Item implementation.
		Should not be instantiated, use L{SessionContextObject.add} instead.

		@type schemaname: C{str}
		@type columnname: C{str}
		@type value: C{str}
		@type matchtype: int
		"""
		__slots__ = ('_prop', '_parent')
		_Prop = plutil.Prop(schemaname=str, columnname=str, value=str, matchtype=int, *plobject._item_props)

		def __str__(self):
			op = {MATCHTYPE_EQUAL: "=",
			      MATCHTYPE_CONTAINS: "contains"}
			return "%s:%s %s %s" % (self._prop.schemaname,
						self._prop.columnname,
						op.get(self._prop.matchtype, "<%d>" % self._prop.matchtype),
						self._prop.value)

		schemaname = property(lambda self: self._prop.schemaname, doc="")
		columnname = property(lambda self: self._prop.columnname, doc="")
		value = property(lambda self: self._prop.value, doc="")
		matchtype = property(lambda self: self._prop.matchtype, doc="")
