"""
This module contains VLANPrioObject implementation.

There is no need to import this module directly. Use the methods of
the L{Ruleset object <ruleset.Ruleset>} to create and manipulate
VLANPrioObjects.

    >>> o = r.object_add("/VLANPrioObjects/Test")
    >>> o.add("4")
    >>> o.add("7")
    >>> print o.items
    ['4', '7']

@var __revision__: Revision identifier.
"""

__revision__ = '%K%'

import plobject
from thisversion import PLDB
import plutil

def _verify_vlanprio(vlan_prio):
	if vlan_prio < 0 or vlan_prio > 7:
		return False
	return True

class VLANPrioObject(plobject.PLObject):
	"""
	VLANPrioObject Implementation

	Object path: /VLANPrioObjects

	@cvar Item: VLANPrioObject Item implementation.
	"""

	__slots__ = ('_prop', '_pldb', '_callback', '_item_added')
	_may_exclude = False

	base_path = plutil.roConst("/VLANPrioObjects", "Only the type portion of the path")
	type = plutil.roConst(PLDB.OBJECT_TYPE_VLANPRIOOBJECT, "Number representing the type of object")

	def _create_item(self, val):
		item = self.Item(self, value=val)

		if not _verify_vlanprio(item._prop.value):
			raise ValueError("First argument doesn't seem like a VLAN prio")

		return item

	def add(self, val):
		"""
		Adds a VLANPrioObject item to this VLANPrioObject.

		@type value: C{str}
		@param value: The value is a string describing the VLANOPriobject item.
				- VLAN PRIO, just give the plain VLAN prio I{0..7}.
		"""
		plobject.PLObject.add(self, val)


	class Item(plobject.PLObject.Item):
		"""
		VLANPrioObject Item implementation.
		Should not be instantiated, use L{VLANPrioObject.add} instead.

		@type value: C{int}
		"""
		__slots__ = ('_prop', '_parent')
		_Prop = plutil.Prop(value=int, *plobject._item_props)

		def __str__(self):
			return str(self._prop.value)

		value = property(lambda self: self._prop.value, doc="VLAN PRIO")
